@@ -43,24 +43,30 @@ where
 /// Generates a new unique name avoiding collisions with the names given in the 'exclusions'.
 /// It takes a preferred name and if it collides it adds an increasing suffix number.
 /// If the preferred name already has a suffix number it starts counting up from this number.
-pub(crate) fn generate_name(exclusions: &[String], preferred_name: String) -> String {
-    fn gen_name(exclusions: &[String], prefix: String, start_num: usize) -> String {
+pub(crate) fn generate_name<T>(exclusions: &[T], preferred_name: String) -> String
+where
+    T: AsRef<str>,
+{
+    fn gen_name<T>(exclusions: &[T], prefix: String, start_num: usize) -> String
+    where
+        T: AsRef<str>,
+    {
         let mut num = start_num;
         let mut new_name = format!("{}{}", prefix, num);
-        while exclusions.contains(&new_name) {
+        while exclusions.iter().any(|n| n.as_ref() == new_name) {
             num += 1;
             new_name = format!("{}{}", prefix, num);
         }
         new_name
     }
 
-    if exclusions.contains(&preferred_name) {
+    if exclusions.iter().any(|n| n.as_ref() == preferred_name) {
         let (suffix_number, prefix) = {
             if let Some(match_) = RX_NUM_SUFFIX.find(&preferred_name) {
                 let num = match_.as_str().parse::<usize>().unwrap_or(1);
                 (num, preferred_name[0..match_.start()].to_string())
             } else {
-                (1, preferred_name.clone())
+                (0, preferred_name.clone())
             }
         };
         gen_name(exclusions, prefix, suffix_number)
